Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2209)

Unified Diff: ash/common/scoped_root_window_for_new_windows.h

Issue 2194353002: mash: Migrate ScopedTargetRootWindow to //ash/common (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: non-virtual Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/aura/wm_shell_aura.cc ('k') | ash/common/scoped_root_window_for_new_windows.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/scoped_root_window_for_new_windows.h
diff --git a/ash/scoped_target_root_window.h b/ash/common/scoped_root_window_for_new_windows.h
similarity index 52%
rename from ash/scoped_target_root_window.h
rename to ash/common/scoped_root_window_for_new_windows.h
index b732e40280766f6edefe2022d9a20de3abab3b29..fd0f49a8901f1b9c25e2ab569a7fc5afc5a6f536 100644
--- a/ash/scoped_target_root_window.h
+++ b/ash/common/scoped_root_window_for_new_windows.h
@@ -2,32 +2,30 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_SCOPED_TARGET_ROOT_WINDOW_H_
-#define ASH_SCOPED_TARGET_ROOT_WINDOW_H_
+#ifndef ASH_COMMON_SCOPED_ROOT_WINDOW_FOR_NEW_WINDOWS_H_
+#define ASH_COMMON_SCOPED_ROOT_WINDOW_FOR_NEW_WINDOWS_H_
#include "ash/ash_export.h"
#include "base/macros.h"
-namespace aura {
-class Window;
-}
-
namespace ash {
-// Constructing a ScopedTargetRootWindow allows temporarily
+class WmWindow;
+
+// Constructing a ScopedRootWindowForNewWindows allows temporarily
// switching a target root window so that a new window gets created
// in the same window where a user interaction happened.
// An example usage is to specify the target root window when creating
// a new window using launcher's icon.
-class ASH_EXPORT ScopedTargetRootWindow {
+class ASH_EXPORT ScopedRootWindowForNewWindows {
public:
- explicit ScopedTargetRootWindow(aura::Window* root_window);
- ~ScopedTargetRootWindow();
+ explicit ScopedRootWindowForNewWindows(WmWindow* new_root);
+ ~ScopedRootWindowForNewWindows();
private:
- DISALLOW_COPY_AND_ASSIGN(ScopedTargetRootWindow);
+ DISALLOW_COPY_AND_ASSIGN(ScopedRootWindowForNewWindows);
};
} // namespace ash
-#endif // ASH_SCOPED_TARGET_ROOT_WINDOW_H_
+#endif // ASH_COMMON_SCOPED_ROOT_WINDOW_FOR_NEW_WINDOWS_H_
« no previous file with comments | « ash/aura/wm_shell_aura.cc ('k') | ash/common/scoped_root_window_for_new_windows.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698